@@ -18,6 +18,7 @@
 // I'm too lazy to set up a skeleton facade for V4L so here it will stay
 mod v4l2;
 #[cfg(all(feature = "input-v4l", target_os = "linux"))]
+#[cfg_attr(feature = "docs-features", doc(cfg(feature = "input-v4l")))]
 pub use v4l2::V4LCaptureDevice;
 #[cfg(any(
     all(feature = "input-msmf", target_os = "windows"),
@@ -28,6 +29,7 @@ mod msmf;
     all(feature = "input-msmf", target_os = "windows"),
     all(feature = "docs-only", feature = "docs-nolink", feature = "input-msmf")
 ))]
+#[cfg_attr(feature = "docs-features", doc(cfg(feature = "input-msmf")))]
 pub use msmf::MediaFoundationCaptureDevice;
 #[cfg(any(
     all(
@@ -52,16 +54,21 @@ mod avfoundation;
         feature = "input-avfoundation"
     )
 ))]
+#[cfg_attr(feature = "docs-features", doc(cfg(feature = "input-avfoundation")))]
 pub use avfoundation::AVFoundationCaptureDevice;
-#[cfg(feature = "input-uvc")]
-mod uvc_backend;
-#[cfg(feature = "input-uvc")]
-pub use uvc_backend::UVCCaptureDevice;
+// FIXME: Fix Lifetime Issues
+// #[cfg(feature = "input-uvc")]
+// mod uvc_backend;
+// #[cfg(feature = "input-uvc")]
+// #[cfg_attr(feature = "docs-features", doc(cfg(feature = "input-uvc")))]
+// pub use uvc_backend::UVCCaptureDevice;
 #[cfg(feature = "input-gst")]
 mod gst_backend;
 #[cfg(feature = "input-gst")]
+#[cfg_attr(feature = "docs-features", doc(cfg(feature = "input-gst")))]
 pub use gst_backend::GStreamerCaptureDevice;
 #[cfg(feature = "input-opencv")]
 mod opencv_backend;
 #[cfg(feature = "input-opencv")]
+#[cfg_attr(feature = "docs-features", doc(cfg(feature = "input-opencv")))]
 pub use opencv_backend::OpenCvCaptureDevice;
