@@ -169,15 +169,15 @@ impl From<FrameFormat> for AVFourCC {
 /// This struct consists of a Width and a Height value (x,y). <br>
 /// Note: the [`Ord`] implementation of this struct is flipped from highest to lowest.
 /// # JS-WASM
-/// This is exported as `Resolution`
-#[cfg_attr(feature = "output-wasm", wasm_bindgen(js_name = Resolution))]
+/// This is exported as `JSResolution`
+#[cfg_attr(feature = "output-wasm", wasm_bindgen(js_name = JSResolution))]
 #[derive(Copy, Clone, Debug, Default, Eq, PartialEq, Hash)]
 pub struct Resolution {
     pub width_x: u32,
     pub height_y: u32,
 }
 
-#[cfg_attr(feature = "output-wasm", wasm_bindgen(js_class = Resolution))]
+#[cfg_attr(feature = "output-wasm", wasm_bindgen(js_class = JSResolution))]
 impl Resolution {
     /// Create a new resolution from 2 image size coordinates.
     /// # JS-WASM
@@ -389,7 +389,7 @@ impl Default for CameraFormat {
         CameraFormat {
             resolution: Resolution::new(640, 480),
             format: FrameFormat::MJPEG,
-            frame_rate: 15,
+            frame_rate: 30,
         }
     }
 }
@@ -470,8 +470,8 @@ impl From<CameraFormat> for CaptureDeviceFormatDescriptor {
 /// `description` amd `misc` may contain information that may differ from backend to backend. Refer to each backend for details.
 /// `index` is a camera's index given to it by (usually) the OS usually in the order it is known to the system.
 /// # JS-WASM
-/// This is exported as a `CameraInfo`.
-#[cfg_attr(feature = "output-wasm", wasm_bindgen(js_name = CameraInfo))]
+/// This is exported as a `JSCameraInfo`.
+#[cfg_attr(feature = "output-wasm", wasm_bindgen(js_name = JSCameraInfo))]
 #[derive(Clone, Debug, Default, Hash, PartialEq, Eq)]
 pub struct CameraInfo {
     human_name: String,
@@ -480,7 +480,7 @@ pub struct CameraInfo {
     index: usize,
 }
 
-#[cfg_attr(feature = "output-wasm", wasm_bindgen(js_class = CameraInfo))]
+#[cfg_attr(feature = "output-wasm", wasm_bindgen(js_class = JSCameraInfo))]
 impl CameraInfo {
     /// Create a new [`CameraInfo`].
     /// # JS-WASM
@@ -741,7 +741,7 @@ impl std::convert::TryFrom<Description> for KnownCameraControls {
             10_094_852 => KnownCameraControls::Pan,
             10_094_853 => KnownCameraControls::Tilt,
             10_094_862 => KnownCameraControls::Zoom,
-            9_963_793 => KnownCameraControls::Exposure,
+            10_094_850 => KnownCameraControls::Exposure,
             10_094_866 => KnownCameraControls::Iris,
             10_094_859 => KnownCameraControls::Focus,
             _ => {
@@ -761,9 +761,17 @@ pub enum KnownCameraControlFlag {
     Manual,
 }
 
+impl Display for KnownCameraControlFlag {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{:?}", self)
+    }
+}
+
 /// This struct tells you everything about a particular [`KnownCameraControls`]. <br>
 /// However, you should never need to instantiate this struct, since its usually generated for you by `nokhwa`.
 /// The only time you should be modifying this struct is when you need to set a value and pass it back to the camera.
+/// NOTE: Assume the values for `min` and `max` as **non-inclusive**!.
+/// E.g. if the [`CameraControl`] says `min` is 100, the minimum is actually 101.
 #[derive(Copy, Clone, Debug, Hash, Eq, PartialEq)]
 pub struct CameraControl {
     control: KnownCameraControls,
@@ -862,6 +870,12 @@ impl CameraControl {
                 error: "Value too low".to_string(),
             });
         }
+        if value == self.minimum_value() || value == self.maximum_value() {
+            return Err(NokhwaError::StructureError {
+                structure: "CameraControl".to_string(),
+                error: "Values not inclusive".to_string(),
+            });
+        }
         if value % self.step() != 0 {
             return Err(NokhwaError::StructureError {
                 structure: "CameraControl".to_string(),
@@ -904,7 +918,7 @@ impl CameraControl {
             step: self.step(),
             default: self.default(),
             flag: self.flag(),
-            active: self.active(),
+            active: true,
         })
     }
 
@@ -935,6 +949,12 @@ impl CameraControl {
         self.active
     }
 
+    /// Gets `active` of this [`CameraControl`],
+    /// telling you weather this control is currently active(in-use).
+    pub fn set_active(&mut self, active: bool) {
+        self.active = active;
+    }
+
     /// Returns a list of i32s that are valid to be set.
     #[allow(clippy::cast_sign_loss)]
     #[must_use]
@@ -946,6 +966,23 @@ impl CameraControl {
     }
 }
 
+impl Display for CameraControl {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(
+            f,
+            "Name: {}, Range: ({}~{}), Current: {}, Step: {}, Default: {}, Flag: {}, Active: {}",
+            self.control,
+            self.min,
+            self.max,
+            self.value,
+            self.step,
+            self.default,
+            self.flag,
+            self.active
+        )
+    }
+}
+
 impl PartialOrd for CameraControl {
     fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
         Some(self.cmp(other))
@@ -984,6 +1021,32 @@ impl Display for CaptureAPIBackend {
     }
 }
 
+/// The `OpenCV` backend supports both native cameras and IP Cameras, so this is an enum to differentiate them
+/// The `IPCamera`'s string follows the pattern
+/// ```.ignore
+/// <protocol>://<IP>:<port>/
+/// ```
+/// but please consult the manufacturer's specification for more details.
+/// The index is a standard webcam index.
+#[derive(Clone, Debug, PartialEq)]
+pub enum CameraIndexType {
+    Index(u32),
+    IPCamera(String),
+}
+
+impl Display for CameraIndexType {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            CameraIndexType::Index(idx) => {
+                write!(f, "{}", idx)
+            }
+            CameraIndexType::IPCamera(ip) => {
+                write!(f, "{}", ip)
+            }
+        }
+    }
+}
+
 /// Converts a MJPEG stream of [u8] into a Vec<u8> of RGB888. (R,G,B,R,G,B,...)
 /// # Errors
 /// If `mozjpeg` fails to read scanlines or setup the decompressor, this will error.
@@ -991,6 +1054,7 @@ impl Display for CaptureAPIBackend {
 /// This function uses `unsafe`. The caller must ensure that:
 /// - The input data is of the right size, does not exceed bounds, and/or the final size matches with the initial size.
 #[cfg(feature = "decoding")]
+#[cfg_attr(feature = "docs-features", doc(cfg(feature = "decoding")))]
 pub fn mjpeg_to_rgb888(data: &[u8]) -> Result<Vec<u8>, NokhwaError> {
     use mozjpeg::Decompress;
 
@@ -1040,6 +1104,7 @@ pub fn mjpeg_to_rgb888(data: &[u8]) -> Result<Vec<u8>, NokhwaError> {
 /// # Errors
 /// This may error when the data stream size is not divisible by 4, a i32 -> u8 conversion fails, or it fails to read from a certain index.
 #[cfg(any(not(target_family = "wasm"), feature = "decoding"))]
+#[cfg_attr(feature = "docs-features", doc(cfg(feature = "decoding")))]
 #[inline]
 pub fn yuyv422_to_rgb888(data: &[u8]) -> Result<Vec<u8>, NokhwaError> {
     use std::convert::TryFrom;
@@ -1051,7 +1116,7 @@ pub fn yuyv422_to_rgb888(data: &[u8]) -> Result<Vec<u8>, NokhwaError> {
                 Some(px) => match i32::try_from(*px) {
                     Ok(i) => i,
                     Err(why) => {
-                        return Err(NokhwaError::ProcessFrameError { src: FrameFormat::YUYV, destination: "RGB888".to_string(), error: format!("Failed to convert byte at {} to a i32 because {}, This shouldn't happen!", px_idx, why.to_string()) });
+                        return Err(NokhwaError::ProcessFrameError { src: FrameFormat::YUYV, destination: "RGB888".to_string(), error: format!("Failed to convert byte at {} to a i32 because {}, This shouldn't happen!", px_idx, why) });
                     }
                 },
                 None => {
@@ -1070,7 +1135,7 @@ pub fn yuyv422_to_rgb888(data: &[u8]) -> Result<Vec<u8>, NokhwaError> {
                 Some(px) => match i32::try_from(*px) {
                     Ok(i) => i,
                     Err(why) => {
-                        return Err(NokhwaError::ProcessFrameError { src: FrameFormat::YUYV, destination: "RGB888".to_string(), error: format!("Failed to convert byte at {} to a i32 because {}, This shouldn't happen!", px_idx+1, why.to_string()) });
+                        return Err(NokhwaError::ProcessFrameError { src: FrameFormat::YUYV, destination: "RGB888".to_string(), error: format!("Failed to convert byte at {} to a i32 because {}, This shouldn't happen!", px_idx+1, why) });
                     }
                 },
                 None => {
@@ -1089,7 +1154,7 @@ pub fn yuyv422_to_rgb888(data: &[u8]) -> Result<Vec<u8>, NokhwaError> {
                 Some(px) => match i32::try_from(*px) {
                     Ok(i) => i,
                     Err(why) => {
-                        return Err(NokhwaError::ProcessFrameError { src: FrameFormat::YUYV, destination: "RGB888".to_string(), error: format!("Failed to convert byte at {} to a i32 because {}, This shouldn't happen!", px_idx+2, why.to_string()) });
+                        return Err(NokhwaError::ProcessFrameError { src: FrameFormat::YUYV, destination: "RGB888".to_string(), error: format!("Failed to convert byte at {} to a i32 because {}, This shouldn't happen!", px_idx+2, why) });
                     }
                 },
                 None => {
@@ -1108,7 +1173,7 @@ pub fn yuyv422_to_rgb888(data: &[u8]) -> Result<Vec<u8>, NokhwaError> {
                 Some(px) => match i32::try_from(*px) {
                     Ok(i) => i,
                     Err(why) => {
-                        return Err(NokhwaError::ProcessFrameError { src: FrameFormat::YUYV, destination: "RGB888".to_string(), error: format!("Failed to convert byte at {} to a i32 because {}, This shouldn't happen!", px_idx+3, why.to_string()) });
+                        return Err(NokhwaError::ProcessFrameError { src: FrameFormat::YUYV, destination: "RGB888".to_string(), error: format!("Failed to convert byte at {} to a i32 because {}, This shouldn't happen!", px_idx+3, why) });
                     }
                 },
                 None => {
@@ -1146,6 +1211,7 @@ pub fn yuyv422_to_rgb888(data: &[u8]) -> Result<Vec<u8>, NokhwaError> {
 #[allow(clippy::cast_sign_loss)]
 #[must_use]
 #[cfg(any(not(target_family = "wasm"), feature = "decoding"))]
+#[cfg_attr(feature = "docs-features", doc(cfg(feature = "decoding")))]
 #[inline]
 pub fn yuyv444_to_rgb888(y: i32, u: i32, v: i32) -> [u8; 3] {
     let c298 = (y - 16) * 298;
@@ -1156,29 +1222,3 @@ pub fn yuyv444_to_rgb888(y: i32, u: i32, v: i32) -> [u8; 3] {
     let b = ((c298 + 516 * d + 128) >> 8).clamp(0, 255) as u8;
     [r, g, b]
 }
-
-/// The `OpenCV` backend supports both native cameras and IP Cameras, so this is an enum to differentiate them
-/// The `IPCamera`'s string follows the pattern
-/// ```.ignore
-/// <protocol>://<IP>:<port>/
-/// ```
-/// but please consult the manufacturer's specification for more details.
-/// The index is a standard webcam index.
-#[derive(Clone, Debug, PartialEq)]
-pub enum CameraIndexType {
-    Index(u32),
-    IPCamera(String),
-}
-
-impl Display for CameraIndexType {
-    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        match self {
-            CameraIndexType::Index(idx) => {
-                write!(f, "{}", idx)
-            }
-            CameraIndexType::IPCamera(ip) => {
-                write!(f, "{}", ip)
-            }
-        }
-    }
-}
